'use strict';

var Benchmark = require('benchmark');
var suite = new Benchmark.Suite;
var parser = require('../lib/utils/parser').default;
var property = require('../lib/utils/property').default;
var util = require('util');

function logOnce(event) {
  if(logOnce.logged) { return; }
  console.log(util.inspect(event, { showHidden: true, depth: null }));
  logOnce.logged = true;
}

var timeStamp;

suite.add('create & dispose', {
  'fn': function() {
    var h = property({
      hello: function(value) {
        return value;
      }
    });
    try {
      h('hello', {});
      h.dispose();
    } catch(e) {
      console.log(e);
    }
  },
  'onCycle':  function(event) {
    var timeBetween = event.timeStamp - timeStamp;
    /*console.log(`
      ${event.type} SinceLast(${timeBetween})
      name: ${event.currentTarget.name}
      hz: ${event.currentTarget.hz}
      maxTime: ${event.currentTarget.maxTime}
      minTime:  ${event.currentTarget.minTime}
      times.cycle: ${event.currentTarget.times.cycle}
      times.elapsed: ${event.currentTarget.times.elapsed}
      times.period: ${event.currentTarget.times.period}
      times.timeStamp: ${event.currentTarget.times.timeStamp}
      count: ${event.currentTarget.count}
      stats.moe: ${event.currentTarget.stats.moe}
      stats.rme: ${event.currentTarget.stats.rme}
      stats.sem: ${event.currentTarget.stats.sem}
      stats.deviation: ${event.currentTarget.stats.deviation}
      stats.mean: ${event.currentTarget.stats.mean}
      stats.variance: ${event.currentTarget.stats.variance}
    `);*/
    //console.log('onCycle', String(event.target));
    timeStamp = event.timeStamp;
  },
  'onComplete':  function(event) {
    console.log('onComplete', String(event.target));
  }
})
.on('cycle', function(event) {
  console.log('cycle', String(event.target));
})
.on('complete', function() {
  console.log('Fastest is ' + this.filter('fastest').map('name'));
})
.run({ 'async': true });
